@@ -18,29 +18,38 @@ HTML_TEMPLATE = email_settings.get("html_template")
 class EmailHandler(Handler):
     """
     Expected data:
-        # provided by the wrapper
-        # ==========================================
-        recipient (User):
-        sender (User): Optional.
+        provided by the wrapper
+        ==========================================
+        recipient (User): The user who receives the email.
+        sender (User): Optional. The user who sends the email.
         template (Template):
         context (dict): Optional.
 
-        # email specific
-        # ==========================================
-        from_email (str):
-        bcc (list): Optional.
-        cc (list): Optional.
-        reply_to (list): Optional.
+        email specific
+        ==========================================
+        from_email (str): Sender's email. If any is set, it will be taken
+            from settings.DEFAULT_FROM
+        bcc (list): Optional. List of emails.
+        cc (list): Optional. List of emails.
+        reply_to (list): Optional. List of emails.
         headers (dict): Optional.
 
-        # template related
-        # ==========================================
-        context["txt_template"] (str):
-        context["html_template"] (str):
+        template related
+        ==========================================
+        context["txt_template"] (str): txt template path
+        context["html_template"] (str): html template path
 
+        # template related (using the default template)
+        image (str): Optional. An image places before the intro: e.g. A logo.
+        image_alt (str): Optional. Image alternative text.
+        intro (str): Optional. A message set before the body.
+        outro (str): Optional. A message set after the body.
+        footer (str): Optional. A message outside the box.
 
         # any other data
         # ==========================================
+        Additional data can be provided, and it will be accessible in the
+        template.
         "foo": "bar",
         "x": 100,
     """
