@@ -1,12 +1,8 @@
 from django.http import HttpResponse
 from django.views.decorators.http import require_POST
 
-from swapper import load_model
-
 from txn_notifications.wrappers import NotificationWrapper
 
-Notification = load_model("notification", "Notification")
-
 
 @require_POST()
 def callbacks(request, handler, callback_id, *args, **kwargs):
